@@ -2,16 +2,16 @@ import os
 from datetime import datetime
 
 import requests
-from six import string_types, text_type
-from typing import Text, Any, Dict, Optional
+from typing import Text, Dict, Optional
 
 from pykechain.enums import ServiceScriptUser, ServiceExecutionStatus
-from pykechain.exceptions import APIError, IllegalArgumentError
-from pykechain.models.base import Base
+from pykechain.exceptions import APIError
+from pykechain.models.base import Base, BaseInScope
+from pykechain.models.input_checks import check_text, check_enum, check_type
 from pykechain.utils import parse_datetime
 
 
-class Service(Base):
+class Service(BaseInScope):
     """
     A virtual object representing a KE-chain Service.
 
@@ -25,8 +25,6 @@ class Service(Base):
     :type description: str
     :ivar version: version number of the service, as provided by uploaded
     :type version: str
-    :ivar scope_id: uuid of the scope to which the service belongs
-    :type scope_id: uuid
     :ivar type: type of the service. One of the :class:`ServiceType`
     :type type: str
     :ivar filename: filename of the service
@@ -45,7 +43,7 @@ class Service(Base):
     """
 
     def __init__(self, json, **kwargs):
-        """Construct a scope from provided json data."""
+        """Construct a service from provided json data."""
         super(Service, self).__init__(json, **kwargs)
         del self.created_at
 
@@ -54,7 +52,6 @@ class Service(Base):
         self.filename = json.get('script_file_name')
         self.type = json.get('script_type')
         self.environment = json.get('env_version')
-        self.scope_id = json.get('scope')  # type: Text
 
         # for SIM3 version
         self.trusted = json.get('trusted')  # type: bool
@@ -65,7 +62,7 @@ class Service(Base):
     def __repr__(self):  # pragma: no cover
         return "<pyke Service '{}' id {}>".format(self.name, self.id[-8:])
 
-    def execute(self, interactive=False):
+    def execute(self, interactive: Optional[bool] = False) -> 'ServiceExecution':
         """
         Execute the service.
 
@@ -82,17 +79,24 @@ class Service(Base):
         response = self._client._request('GET', url, params=dict(interactive=interactive, format='json'))
 
         if response.status_code == requests.codes.conflict:  # pragma: no cover
-            raise APIError("Conflict: Could not execute service as it is already running '{}': {}".
-                           format(self, (response.status_code, response.json())))
+            raise APIError(
+                "Conflict: Could not execute Service {} as it is already running.".format(self), response=response)
         elif response.status_code != requests.codes.accepted:  # pragma: no cover
             raise APIError(
-                "Could not execute service '{}': {}".format(self, (response.status_code, response.json())))
+                "Could not execute Service {}".format(self), response=response)
 
         data = response.json()
         return ServiceExecution(json=data.get('results')[0], client=self._client)
 
-    def edit(self, name=None, description=None, version=None, run_as=None, trusted=False, **kwargs):
-        # type: (Text, Text, Text, ServiceScriptUser, bool, **Any) -> None
+    def edit(
+            self,
+            name: Optional[Text] = None,
+            description: Optional[Text] = None,
+            version: Optional[Text] = None,
+            run_as: Optional[ServiceScriptUser] = None,
+            trusted: Optional[bool] = False,
+            **kwargs
+    ) -> None:
         """
         Edit Service details.
 
@@ -111,41 +115,31 @@ class Service(Base):
         :raises IllegalArgumentError: when you provide an illegal argument.
         :raises APIError: if the service could not be updated.
         """
-        update_dict = {'id': self.id}
-        if name is not None:
-            if not isinstance(name, (string_types, text_type)):
-                raise IllegalArgumentError("name should be provided as a string")
-            update_dict.update({'name': name})
-        if description is not None:
-            if not isinstance(description, (string_types, text_type)):
-                raise IllegalArgumentError("description should be provided as a string")
-            update_dict.update({'description': description})
-        if version is not None:
-            if not isinstance(version, (string_types, text_type)):
-                raise IllegalArgumentError("description should be provided as a string")
-            update_dict.update({'script_version': version})
-        if run_as is not None:
-            if not isinstance(run_as, (string_types, text_type)) and run_as not in ServiceScriptUser.values():
-                raise IllegalArgumentError("run_as should be provided as one of '{}'".format(
-                    ServiceScriptUser.values()))
-            update_dict.update({'run_as': run_as})
-        if not isinstance(trusted, bool):
-            raise IllegalArgumentError("trusted should be provided as a boolean")
-        else:
-            update_dict.update({'trusted': trusted})
+        update_dict = {
+            'id': self.id,
+            'name': check_text(name, 'name') or self.name,
+            'description': check_text(description, 'description') or self.description,
+            'trusted': check_type(trusted, bool, 'trusted')
+        }
+        run_as = check_enum(run_as, ServiceScriptUser, 'run_as')
+        if run_as:
+            update_dict['run_as'] = run_as
+        version = check_text(version, 'version')
+        if version:
+            update_dict['script_version'] = version
 
-        if kwargs is not None:  # pragma: no cover
+        if kwargs:  # pragma: no cover
             update_dict.update(**kwargs)
+
         response = self._client._request('PUT', self._client._build_url('service', service_id=self.id),
                                          json=update_dict)
 
         if response.status_code != requests.codes.ok:  # pragma: no cover
-            raise APIError("Could not update Service ({})".format(response))
+            raise APIError("Could not update Service {}".format(self), response=response)
 
         self.refresh(json=response.json()['results'][0])
 
-    def delete(self):
-        # type: () -> None
+    def delete(self) -> None:
         """Delete this service.
 
         :raises APIError: if delete was not successful.
@@ -153,7 +147,7 @@ class Service(Base):
         response = self._client._request('DELETE', self._client._build_url('service', service_id=self.id))
 
         if response.status_code != requests.codes.no_content:  # pragma: no cover
-            raise APIError("Could not delete service: {} with id {}".format(self.name, self.id))
+            raise APIError("Could not delete Service {}".format(self), response=response)
 
     def upload(self, pkg_path):
         """
@@ -181,7 +175,7 @@ class Service(Base):
             )
 
         if response.status_code != requests.codes.accepted:  # pragma: no cover
-            raise APIError("Could not upload service script file (or kecpkg) ({})".format(response))
+            raise APIError("Could not upload script file (or kecpkg) to Service {}".format(self), response=response)
 
         self.refresh(json=response.json()['results'][0])
 
@@ -203,7 +197,7 @@ class Service(Base):
         url = self._client._build_url('service_download', service_id=self.id)
         response = self._client._request('GET', url)
         if response.status_code != requests.codes.ok:  # pragma: no cover
-            raise APIError("Could not download service script file ({})".format(response))
+            raise APIError("Could not download script file from Service {}".format(self), response=response)
 
         with open(full_path, 'w+b') as f:
             for chunk in response:
@@ -269,7 +263,7 @@ class ServiceExecution(Base):
         return "<pyke ServiceExecution '{}' id {}>".format(self.name, self.id[-8:])
 
     @property
-    def service(self):
+    def service(self) -> Service:
         """Retrieve the `Service` object to which this execution is associated."""
         if not self._service:
             self._service = self._client.service(id=self.service_id)
@@ -288,7 +282,7 @@ class ServiceExecution(Base):
         response = self._client._request('GET', url, params=dict(format='json'))
 
         if response.status_code != requests.codes.accepted:  # pragma: no cover
-            raise APIError("Could not execute service '{}': {}".format(self, response))
+            raise APIError("Could not terminate Service {}".format(self), response=response)
 
     def get_log(self, target_dir=None, log_filename='log.txt'):
         """
@@ -308,7 +302,7 @@ class ServiceExecution(Base):
         url = self._client._build_url('service_execution_log', service_execution_id=self.id)
         response = self._client._request('GET', url)
         if response.status_code != requests.codes.ok:  # pragma: no cover
-            raise APIError("Could not download service execution log")
+            raise APIError("Could not download execution log of Service {}".format(self), response=response)
 
         with open(full_path, 'w+b') as f:
             for chunk in response:
@@ -327,7 +321,7 @@ class ServiceExecution(Base):
         response = self._client._request('GET', url, params=dict(format='json'))
 
         if response.status_code != requests.codes.ok:
-            raise APIError("Could not retrieve notebook url '{}': {}".format(self, response))
+            raise APIError("Could not retrieve notebook url of Service {}".format(self), response=response)
 
         data = response.json()
         url = data.get('results')[0].get('url')
