@@ -204,6 +204,7 @@ class WidgetsManager(Iterable):
                              edit: Optional[bool] = True,
                              clone: Optional[bool] = True,
                              export: Optional[bool] = True,
+                             upload: Optional[bool] = True,
                              delete: Optional[bool] = False,
                              incomplete_rows: Optional[bool] = True,
                              emphasize_new_instance: Optional[bool] = True,
@@ -243,6 +244,8 @@ class WidgetsManager(Iterable):
         :type clone: bool
         :param export: Show or hide the Export Grid button (default True)
         :type export: bool
+        :param upload: Show or hide the Import Grid button (default True)
+        :type upload: bool
         :param delete: Show or hide the Delete button (default False)
         :type delete: bool
         :param incomplete_rows: Show or hide the Incomplete Rows filter button (default True)
@@ -299,6 +302,7 @@ class WidgetsManager(Iterable):
             "deleteButtonVisible": delete,
             "cloneButtonVisible": clone,
             "downloadButtonVisible": export,
+            "uploadButtonVisible": upload,
             "incompleteRowsVisible": incomplete_rows,
             "primaryAddUiValue": emphasize_new_instance,
             "primaryEditUiValue": emphasize_edit,
@@ -334,6 +338,7 @@ class WidgetsManager(Iterable):
                                 edit: Optional[bool] = True,
                                 clone: Optional[bool] = True,
                                 export: Optional[bool] = True,
+                                upload: Optional[bool] = True,
                                 delete: Optional[bool] = False,
                                 incomplete_rows: Optional[bool] = True,
                                 emphasize_new_instance: Optional[bool] = True,
@@ -378,6 +383,8 @@ class WidgetsManager(Iterable):
         :type clone: bool
         :param export: Show or hide the Export Grid button (default True)
         :type export: bool
+        :param upload: Show or hide the Import Grid button (default True)
+        :type upload: bool
         :param delete: Show or hide the Delete button (default False)
         :type delete: bool
         :param incomplete_rows: Show or hide the Incomplete Rows filter button (default True)
@@ -461,6 +468,7 @@ class WidgetsManager(Iterable):
             "deleteButtonVisible": delete,
             "cloneButtonVisible": clone,
             "downloadButtonVisible": export,
+            "uploadButtonVisible": upload,
             "incompleteRowsVisible": incomplete_rows,
             "primaryAddUiValue": emphasize_new_instance,
             "primaryEditUiValue": emphasize_edit,
@@ -1385,6 +1393,50 @@ class WidgetsManager(Iterable):
         )
         return widget
 
+    def add_weather_widget(self,
+                           weather_property: 'Property2',
+                           autofill: Optional[bool] = None,
+                           title: Optional[Union[bool, Text]] = False,
+                           parent_widget: Optional[Union[Widget, Text]] = None,
+
+                           **kwargs) -> Widget:
+        """
+        Add a KE-chain Weather widget to the Widgetmanager and the activity.
+
+        The widget will be saved in KE-chain.
+
+        :param weather_property: KE-chain Weather property to display
+        :type weather_property: Property2
+        :param title: A custom title for the script widget
+            * False (default): Script name
+            * String value: Custom title
+            * None: No title
+        :type title: bool or basestring or None
+        :param kwargs: additional keyword arguments to pass
+        :return: newly created widget
+        :rtype: Widget
+        :raises IllegalArgumentError: when incorrect arguments are provided
+        :raises APIError: When the widget could not be created.
+        """
+        weather_property = _retrieve_object(weather_property,
+                                            method=self._client.property)  # type: 'Property2'  # noqa
+        meta = _initiate_meta(kwargs, activity=self._activity_id)
+        meta, title = _set_title(meta, title=title, default_title=weather_property.name, **kwargs)
+
+        meta.update({
+            "propertyInstanceId": weather_property.id,
+        })
+
+        widget = self.create_widget(
+            widget_type=WidgetTypes.WEATHER,
+            meta=meta,
+            title=title,
+            parent=parent_widget,
+            writable_models=[weather_property.model_id],
+            **kwargs,
+        )
+        return widget
+
     #
     # Widget manager methods
     #
